==> ec2-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnEIPProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::EIP`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:13:21.578Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnEIPProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::EIP.Domain`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-domain
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomain();
    /**
     * `AWS::EC2::EIP.InstanceId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-instanceid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstanceId();
    /**
     * `AWS::EC2::EIP.PublicIpv4Pool`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-publicipv4pool
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getPublicIpv4Pool();

    /**
     * @return a {@link Builder} of {@link CfnEIPProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnEIPProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.String _domain;
        @javax.annotation.Nullable
        private java.lang.String _instanceId;
        @javax.annotation.Nullable
        private java.lang.String _publicIpv4Pool;

        /**
         * Sets the value of Domain
         * @param value `AWS::EC2::EIP.Domain`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDomain(@javax.annotation.Nullable final java.lang.String value) {
            this._domain = value;
            return this;
        }
        /**
         * Sets the value of InstanceId
         * @param value `AWS::EC2::EIP.InstanceId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withInstanceId(@javax.annotation.Nullable final java.lang.String value) {
            this._instanceId = value;
            return this;
        }
        /**
         * Sets the value of PublicIpv4Pool
         * @param value `AWS::EC2::EIP.PublicIpv4Pool`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withPublicIpv4Pool(@javax.annotation.Nullable final java.lang.String value) {
            this._publicIpv4Pool = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnEIPProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnEIPProps build() {
            return new CfnEIPProps() {
                @javax.annotation.Nullable
                private final java.lang.String $domain = _domain;
                @javax.annotation.Nullable
                private final java.lang.String $instanceId = _instanceId;
                @javax.annotation.Nullable
                private final java.lang.String $publicIpv4Pool = _publicIpv4Pool;

                @Override
                public java.lang.String getDomain() {
                    return this.$domain;
                }

                @Override
                public java.lang.String getInstanceId() {
                    return this.$instanceId;
                }

                @Override
                public java.lang.String getPublicIpv4Pool() {
                    return this.$publicIpv4Pool;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getDomain() != null) {
                        obj.set("domain", om.valueToTree(this.getDomain()));
                    }
                    if (this.getInstanceId() != null) {
                        obj.set("instanceId", om.valueToTree(this.getInstanceId()));
                    }
                    if (this.getPublicIpv4Pool() != null) {
                        obj.set("publicIpv4Pool", om.valueToTree(this.getPublicIpv4Pool()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnEIPProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::EIP.Domain`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-domain
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getDomain() {
            return this.jsiiGet("domain", java.lang.String.class);
        }

        /**
         * `AWS::EC2::EIP.InstanceId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-instanceid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getInstanceId() {
            return this.jsiiGet("instanceId", java.lang.String.class);
        }

        /**
         * `AWS::EC2::EIP.PublicIpv4Pool`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-publicipv4pool
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getPublicIpv4Pool() {
            return this.jsiiGet("publicIpv4Pool", java.lang.String.class);
        }
    }
}

==> ec2-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnEIPProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::EIP`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:06:47.504Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnEIPProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::EIP.Domain`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-domain
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDomain();
    /**
     * `AWS::EC2::EIP.InstanceId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-instanceid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getInstanceId();
    /**
     * `AWS::EC2::EIP.PublicIpv4Pool`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-publicipv4pool
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getPublicIpv4Pool();

    /**
     * @return a {@link Builder} of {@link CfnEIPProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnEIPProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.String _domain;
        @javax.annotation.Nullable
        private java.lang.String _instanceId;
        @javax.annotation.Nullable
        private java.lang.String _publicIpv4Pool;

        /**
         * Sets the value of Domain
         * @param value `AWS::EC2::EIP.Domain`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDomain(@javax.annotation.Nullable final java.lang.String value) {
            this._domain = value;
            return this;
        }
        /**
         * Sets the value of InstanceId
         * @param value `AWS::EC2::EIP.InstanceId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withInstanceId(@javax.annotation.Nullable final java.lang.String value) {
            this._instanceId = value;
            return this;
        }
        /**
         * Sets the value of PublicIpv4Pool
         * @param value `AWS::EC2::EIP.PublicIpv4Pool`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withPublicIpv4Pool(@javax.annotation.Nullable final java.lang.String value) {
            this._publicIpv4Pool = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnEIPProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnEIPProps build() {
            return new CfnEIPProps() {
                @javax.annotation.Nullable
                private final java.lang.String $domain = _domain;
                @javax.annotation.Nullable
                private final java.lang.String $instanceId = _instanceId;
                @javax.annotation.Nullable
                private final java.lang.String $publicIpv4Pool = _publicIpv4Pool;

                @Override
                public java.lang.String getDomain() {
                    return this.$domain;
                }

                @Override
                public java.lang.String getInstanceId() {
                    return this.$instanceId;
                }

                @Override
                public java.lang.String getPublicIpv4Pool() {
                    return this.$publicIpv4Pool;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getDomain() != null) {
                        obj.set("domain", om.valueToTree(this.getDomain()));
                    }
                    if (this.getInstanceId() != null) {
                        obj.set("instanceId", om.valueToTree(this.getInstanceId()));
                    }
                    if (this.getPublicIpv4Pool() != null) {
                        obj.set("publicIpv4Pool", om.valueToTree(this.getPublicIpv4Pool()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnEIPProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::EIP.Domain`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-domain
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getDomain() {
            return this.jsiiGet("domain", java.lang.String.class);
        }

        /**
         * `AWS::EC2::EIP.InstanceId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-instanceid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getInstanceId() {
            return this.jsiiGet("instanceId", java.lang.String.class);
        }

        /**
         * `AWS::EC2::EIP.PublicIpv4Pool`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-eip.html#cfn-ec2-eip-publicipv4pool
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getPublicIpv4Pool() {
            return this.jsiiGet("publicIpv4Pool", java.lang.String.class);
        }
    }
}
